@@ -8,9 +8,11 @@ from .cli_commands.create import create_command
 from .cli_commands.deploy import deploy_command
 from .cli_commands.init import init_command
 from .cli_commands.prepare_env import prepare_env_command
+from .cli_commands.publish import publish_command
 from .cli_commands.run import run_command
 from .cli_commands.template import list_templates_command
 from .cli_commands.test import test_command
+from .cli_commands.update import update_command
 from .cli_utils import echo_error
 from .errors import DataPipelinesError
 
@@ -35,6 +37,8 @@ _cli.add_command(create_command)
 _cli.add_command(deploy_command)
 _cli.add_command(init_command)
 _cli.add_command(prepare_env_command)
+_cli.add_command(publish_command)
 _cli.add_command(run_command)
 _cli.add_command(list_templates_command)
 _cli.add_command(test_command)
+_cli.add_command(update_command)
